Skip to content

Commit 834799b

Browse files
committed
feat: tiny change for test
1 parent b4f67bd commit 834799b

1 file changed

Lines changed: 1 addition & 0 deletions

File tree

relu/relu_cuda/relu.cu

Lines changed: 1 addition & 0 deletions
Original file line numberDiff line numberDiff line change
@@ -10,6 +10,7 @@ __global__ void relu_kernel(float *__restrict__ out,
1010
for (int64_t idx = threadIdx.x; idx < d; idx += blockDim.x) {
1111
auto x = input[token_idx * d + idx];
1212
out[token_idx * d + idx] = x > 0.0f ? x : 0.0f;
13+
out[token_idx * d + idx] += 0.1f; // test change
1314
}
1415
}
1516

0 commit comments

Comments
 (0)